/**
  *  \file client/chart/drawcirclemode.cc
  *  \brief Starchart Mode: WDrawCircleChartMode
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/chart/drawcirclemode.h"
#include "client/chartloc.h"
#include "client/dialogs/helpdlg.h"
#include "cpluslib/format.h"
#include "game/formula.h"
#include "gfx/gfxcontext.h"
#include "gfx/palette.h"
#include "ui/event.h"
#include "ui/uiglobal.h"
#include "util/nls.h"

WDrawCircleChartMode::WDrawCircleChartMode(GDrawingContainer::iterator p)
    : WMarkerChartMode(p)
{ }

WDrawCircleChartMode::~WDrawCircleChartMode()
{ }

void
WDrawCircleChartMode::setRadius(int n)
{
    if (n > 0 && n < 1000 /* FIXME! */ && *drawing) {
        (*drawing)->setCircleRadius(n);
        getParent()->markChanged();
    }
}

void
WDrawCircleChartMode::onMove(GChartLocation& loc)
{
    // Normally, user interface state should be checked in handleEvent(),
    // but this way it's much simpler.
    // FIXME: we should handle getWrapAdjust(). However, we shouldn't blindly
    // modify getCenter() and generate out-of-map circles.
    if (getCurrentModifierKeys() & ss_Alt) {
        if (*drawing) {
            setRadius(roundToInt(std::sqrt(double(distanceSquared(loc.getLocation(), (*drawing)->getPos())))));
        }
    }

    WMarkerChartMode::onMove(loc);
}

void
WDrawCircleChartMode::drawOverlays(GfxCanvas& can, GChartLocation& loc)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(GfxStandardColorScheme::instance);
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setColor(COLOR_WHITE);

    GfxPoint sc = loc.getViewport().view.getTopLeft();
    outText(ctx, sc.x, sc.y, _("Set circle size with [+]/[-], end with [ESC]."));
    if (*drawing) {
        outText(ctx, sc.x, sc.y + font_heights[FONT_NORMAL], format(_("Radius: %d ly"), (*drawing)->getCircleRadius()));
    }

    WMarkerChartMode::drawOverlays(can, loc);
}

bool
WDrawCircleChartMode::handleEvent(const UIEvent& event, GChartLocation& loc)
{
    if (event.type == ev_Key) {
        if (!*drawing) {
            // FIXME: hack
            delete this;
            return true;
        }
        switch (event.key.code) {
         case '+':
            setRadius((*drawing)->getCircleRadius() + (event.key.arg ? event.key.arg : 10));
            return true;
         case '-':
            setRadius((*drawing)->getCircleRadius() - (event.key.arg ? event.key.arg : 10));
            return true;
         case ss_Shift + '+':
            setRadius((*drawing)->getCircleRadius() + 1);
            return true;
         case ss_Shift + '-':
            setRadius((*drawing)->getCircleRadius() - 1);
            return true;
         case '=':
            if (event.key.arg) {
                setRadius(event.key.arg);
            }
            return true;
         case 'y':
            setRadius(350);
            return true;
         case SDLK_BACKSPACE:
            loc.setLocation((*drawing)->getPos());
            return true;
         case 'h':
         case ss_Alt + 'h':
            doHelp("pcc2:draw");
            return true;
        }
    }

    return WMarkerChartMode::handleEvent(event, loc);
}
