/**
  *  \file client/widgets/teamname.cc
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/teamname.h"
#include "cpluslib/format.h"
#include "game/struct.h"
#include "game/team.h"
#include "ui/skin.h"
#include "ui/uiglobal.h"
#include "util/nls.h"

WTeamName::WTeamName()
    : conn_team_change(observe(sig_team_change)),
      team(1)
{ }

WTeamName::~WTeamName()
{ }

void
WTeamName::setTeam(int team)
{
    if (team != this->team && team >= 1 && team <= NUM_PLAYERS) {
        this->team = team;
        drawWidget();
    }
}

void
WTeamName::getLayoutInfo(LayoutInfo& info)
{
    info.min_size = info.pref_size = font_sizes[FONT_NORMAL].scaledBy(25, 1);
}

void
WTeamName::drawContent(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.setColor(UIColor::tc_Static);
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setSolidBackground();

    string_t name = format(_("Team %d"), team);
    if (isNamedTeam(team)) {
        name += ": ";
        name += getTeamName(team);
    }
    outTextF(ctx,
             getExtent().x,
             getExtent().y + (getExtent().h - font_heights[FONT_NORMAL]) / 2,
             getExtent().w,
             name);
    can.update(getExtent());
}
