/**
  *  \file io/nullstream.h
  *  \brief Null stream (data sink)
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_IO_NULLSTREAM_H
#define PCC_V2_IO_NULLSTREAM_H

#include "io/streams.h"

/** Null stream. This stream discards all data written to it. When
    read, it behaves like an empty file. It tracks a current position
    and size. */
class NullStream : public Stream {
    std::size_t pos, size;
 public:
    NullStream();
    ~NullStream();
    std::size_t read(char* buffer, std::size_t nbytes);
    std::size_t write(const char* buffer, std::size_t nbytes);
    int         getCapabilities() const;
    void        seek(fpos_t pos);
    fpos_t      getSize();
    fpos_t      getPos();
    string_t    getName();
};

#endif
